<?php declare(strict_types=1);

namespace Plugin\css_OrderAttribute\Migrations;

use JTL\Shop;
use JTL\Jtllog;


use JTL\Plugin\Migration;
use JTL\Update\IMigration;


/**
 * Class Migration20241904123301
 * @package Plugin\jtl_test\Migrations
 */
class Migration20241904123301 extends Migration implements IMigration {
	/**
	 * @inheritdoc
	 */


	public function columnExist($table, $field) {
		// false bedeutet das es die Spalte nicht gibt
		return $this->getDB()->query("Show columns from `" . $table . "` like '" . $field . "' ", 1);
	}

	public function tableExist($table) {
		// in Rows steht die Anzahl der Zeilen, false bedeutet das es die Tabelle nicht gibt
		$obj =  $this->getDB()->query("SHOW TABLE STATUS  like '" . $table . "'", 1);
		if($obj && (int) $obj->Rows == 0) {
			$o = $this->getDB()->query("SELECT COUNT(*) AS anzahl FROM " . $table . " WHERE 1",1);
			$obj->Rows = (int) $o->anzahl;
			return $obj;
		}
		return $obj;
	}


	public function copyTable($sourceDB, $destinationDB = "", $copyTable = true, $deleteSourceDB = false) {
		error_log('starte copy ' . $sourceDB);
		$result = $this->getDB()->query("SHOW TABLES LIKE '" . $sourceDB . "'", 2);
		if ($copyTable && $result !== null && is_array($result) && count($result)) {
			error_log('DB Vorhanden ' . $sourceDB);
			$result = $this->getDB()->query("SELECT * FROM " . $sourceDB . " WHERE 1", 2);
			foreach ($result as $oItem) {
				error_log('schreibe Datensatz nach ' . $destinationDB);
				$this->getDB()->insert($destinationDB, $oItem);
			}
		}
		if ($deleteSourceDB) {
			$this->execute("DROP TABLE IF EXISTS " . $sourceDB, 3);
		}
	}


	/*
	define('JTLLOG_LEVEL_EMERGENCY', 600);
	define('JTLLOG_LEVEL_ALERT', 550);
	define('JTLLOG_LEVEL_CRITICAL', 500);
	define('JTLLOG_LEVEL_ERROR', 400);
	define('JTLLOG_LEVEL_WARNING', 300);
	define('JTLLOG_LEVEL_NOTICE', 250);
	define('JTLLOG_LEVEL_INFO', 200);
	define('JTLLOG_LEVEL_DEBUG', 100);
*/

	public function JTLWriteLog($cLog = '', $nLevel = JTLLOG_LEVEL_INFO, $bForce = false) {
		if (\mb_strlen($cLog) > 0 && ($bForce || Jtllog::getSytemlogFlag(false))) {
			$logger = Shop::Container()->getLogService();
			$logger = $logger->withName("css_OrderAttribute");
			$logger->log($nLevel, $cLog, ["css_OrderAttribute"]);
			return true;
		}
		return false;
	}


	public function up() {

		$this->execute("
								CREATE TABLE IF NOT EXISTS `css_OrderAttributeOptions` (
								  `id` int(10) NOT NULL AUTO_INCREMENT,
								  `pid` int(10) NOT NULL DEFAULT 0,
								  `cValue` Text NOT NULL,
								  `nSort` int(10) NOT NULL DEFAULT 0,
								  `gridXS` varchar(5) NOT NULL DEFAULT 'auto',
								  `gridSM` varchar(5) NOT NULL DEFAULT 'auto',
								  `gridMD` varchar(5) NOT NULL DEFAULT 'auto',
								  `gridLG` varchar(5) NOT NULL DEFAULT 'auto',
								  PRIMARY KEY (`id`)
               ) ENGINE=InnoDB COLLATE utf8_unicode_ci
        ");

		if(!self::columnExist('css_OrderAttributeData','nWidth')) {
			$this->execute("
										ALTER TABLE `css_OrderAttributeData` ADD `nWidth` INT(4) NOT NULL DEFAULT '0';
										");
		}
		$this->execute("
										ALTER TABLE `css_OrderAttributeConfig` CHANGE `framework` `framework` VARCHAR(20)
										");

		$this->execute("
										ALTER TABLE `css_OrderAttributeConfig` CHANGE `selector_position` `selector_position` VARCHAR(15)
										");


		if(($obj = $this->tableExist('css_OrderAttributeConfig')) && $obj->Rows > 0) {
			$this->execute("UPDATE css_OrderAttributeConfig set `version` = '2.0.0' ");
		} else {
			$this->execute(
				"INSERT INTO `css_OrderAttributeConfig` (`version`) VALUES ('2.0.0')"
			);
		}


	}

	/**
	 * @inheritdoc
	 */
	public function down() {
	}
}
